@@ -1,12 +1,12 @@
 /**
  * \file agShell
  *
- *  Time-stamp:        "2010-12-09 11:55:08 bkorb"
+ *  Time-stamp:        "2011-02-01 07:38:34 bkorb"
  *
  *  Manage a server shell process
  *
  *  This file is part of AutoGen.
- *  AutoGen Copyright (c) 1992-2010 by Bruce Korb - all rights reserved
+ *  AutoGen Copyright (c) 1992-2011 by Bruce Korb - all rights reserved
  *
  * AutoGen is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -24,12 +24,6 @@
 #ifndef SHELL_ENABLED
  void  closeServer(void) { }
 
- int   chainOpen(int stdinFd, tCC** ppArgs, pid_t* pChild) { return -1; }
-
- pid_t openServer(tFdPair* pPair, tCC** ppArgs) { return NOPROCESS; }
-
- pid_t openServerFP(tpfPair* pfPair, tCC** ppArgs) { return NOPROCESS; }
-
  char* runShell(char const* pzCmd) {
      char* pz;
      AGDUPSTR(pz, pzCmd, "dummy shell command");
@@ -55,6 +49,15 @@ handle_signal(int signo);
 static void
 server_setup(void);
 
+static int
+chain_open(int stdinFd, char const ** ppArgs, pid_t * pChild);
+
+static pid_t
+server_open(tFdPair* pPair, char const ** ppArgs);
+
+static pid_t
+server_fp_open(tpfPair* pfPair, char const ** ppArgs);
+
 static void
 realloc_text(char ** p_txt, size_t * p_sz, size_t need_len);
 
@@ -179,9 +182,10 @@ server_setup(void)
     }
 
     if (OPT_VALUE_TRACE >= TRACE_EVERYTHING) {
-        tSCC zSetup[] = "set -x\n"
-                        "trap\n"
-                        "echo server setup done\n";
+        static char const zSetup[] =
+            "set -x\n"
+            "trap\n"
+            "echo server setup done\n";
         char* pz;
 
         fputs("Server traps set\n", pfTrace);
@@ -211,12 +215,12 @@ server_setup(void)
  *  for the new process and, optionally, a pointer to a place
  *  to store the child's process id.
  */
-LOCAL int
-chainOpen(int stdinFd, char const ** ppArgs, pid_t * pChild)
+static int
+chain_open(int stdinFd, char const ** ppArgs, pid_t * pChild)
 {
     tFdPair   stdoutPair = { -1, -1 };
     pid_t     chId;
-    tCC*      pzShell;
+    char const *      pzShell;
 
     /*
      *  If we did not get an arg list, use the default
@@ -328,8 +332,8 @@ chainOpen(int stdinFd, char const ** ppArgs, pid_t * pChild)
  *  process should write to "writeFd" and read from "readFd".
  *  The return value is the process id of the created process.
  */
-LOCAL pid_t
-openServer(tFdPair* pPair, tCC** ppArgs)
+static pid_t
+server_open(tFdPair* pPair, char const ** ppArgs)
 {
     pid_t chId = NOPROCESS;
 
@@ -341,7 +345,7 @@ openServer(tFdPair* pPair, tCC** ppArgs)
     if (pipe((int*)pPair) < 0)
         return NOPROCESS;
 
-    pPair->readFd = chainOpen(pPair->readFd, ppArgs, &chId);
+    pPair->readFd = chain_open(pPair->readFd, ppArgs, &chId);
     if (chId == NOPROCESS)
         close(pPair->writeFd);
 
@@ -350,14 +354,14 @@ openServer(tFdPair* pPair, tCC** ppArgs)
 
 
 /**
- *  Identical to "openServer()", except that the "fd"'s are "fdopen(3)"-ed
+ *  Identical to "server_open()", except that the "fd"'s are "fdopen(3)"-ed
  *  into file pointers instead.
  */
-LOCAL pid_t
-openServerFP(tpfPair* pfPair, tCC** ppArgs)
+static pid_t
+server_fp_open(tpfPair* pfPair, char const ** ppArgs)
 {
     tFdPair   fdPair;
-    pid_t     chId = openServer(&fdPair, ppArgs);
+    pid_t     chId = server_open(&fdPair, ppArgs);
 
     if (chId == NOPROCESS)
         return chId;
@@ -482,7 +486,8 @@ load_data(void)
 LOCAL char*
 runShell(char const*  pzCmd)
 {
-    tSCC zCmdFail[] = "CLOSING SHELL SERVER - command failure:\n\t%s\n";
+    static char const zCmdFail[] =
+        "CLOSING SHELL SERVER - command failure:\n\t%s\n";
 
     /*
      *  IF the shell server process is not running yet,
@@ -491,7 +496,7 @@ runShell(char const*  pzCmd)
     if (serv_id == NULLPROCESS) {
         static char pz4_z[] = "PS4=>ag> ";
         putenv(pz4_z);
-        serv_id = openServerFP(&serv_pair, serverArgs);
+        serv_id = server_fp_open(&serv_pair, serverArgs);
         if (serv_id > 0)
             server_setup();
     }
