@@ -1,15 +1,13 @@
 
-/*
- *  autogen.c
- *  $Id: autogen.c,v 4.30 2009/01/01 16:51:41 bkorb Exp $
+/**
+ *  \file autogen.c
  *
- *  Time-stamp:        "2008-08-17 15:30:54 bkorb"
- *  Last Committed:    $Date: 2009/01/01 16:51:41 $
+ *  Time-stamp:        "2011-02-01 14:31:45 bkorb"
  *
  *  This is the main routine for autogen.
  *
  *  This file is part of AutoGen.
- *  AutoGen copyright (c) 1992-2009 by Bruce Korb - all rights reserved
+ *  AutoGen Copyright (c) 1992-2011 by Bruce Korb - all rights reserved
  *
  * AutoGen is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -24,49 +22,72 @@
  * You should have received a copy of the GNU General Public License along
  * with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
+#ifdef HAVE_SYS_RESOURCE_H
+#include <sys/resource.h>
+#endif
 
-tSCC zClientInput[] = "client-input";
+typedef void (void_main_proc_t)(int, char **);
+
+typedef enum {
+    EXIT_PCLOSE_WAIT,
+    EXIT_PCLOSE_NOWAIT
+} wait_for_pclose_enum_t;
+
+static char const zClientInput[] = "client-input";
 
 #define _State_(n)  #n,
-tSCC* apzStateName[] = { STATE_TABLE };
+static char const * const state_names[] = { STATE_TABLE };
 #undef _State_
 
 static sigjmp_buf  abendJumpEnv;
 static int         abendJumpSignal = 0;
 
-typedef void (sighandler_proc_t)( int sig );
-static sighandler_proc_t ignoreSignal, abendSignal;
+typedef void (sighandler_proc_t)(int sig);
+static sighandler_proc_t ignore_signal, catch_sig_and_bail;
 
 /* = = = START-STATIC-FORWARD = = = */
-/* static forward declarations maintained by mk-fwd */
 static void
-inner_main( int argc, char** argv );
+inner_main(
+#if GUILE_VERSION >= 108000
+    void * closure,
+#endif
+    int argc, char ** argv);
 
 static void
-signalExit( int sig );
+exit_cleanup(wait_for_pclose_enum_t cl_wait);
 
 static void
-abendSignal( int sig );
+cleanup_and_abort(int sig);
 
 static void
-ignoreSignal( int sig );
+catch_sig_and_bail(int sig);
 
 static void
-doneCheck( void );
+ignore_signal(int sig);
 
 static void
-signalSetup( sighandler_proc_t* chldHandler,
-             sighandler_proc_t* dfltHandler );
+done_check(void);
+
+static void
+setup_signals(sighandler_proc_t * chldHandler,
+              sighandler_proc_t * abrtHandler,
+              sighandler_proc_t * dfltHandler);
 /* = = = END-STATIC-FORWARD = = = */
 
+/**
+ * main routine under Guile guidance
+ */
 static void
-inner_main( int argc, char** argv )
+inner_main(
+#if GUILE_VERSION >= 108000
+    void * closure,
+#endif
+    int argc, char ** argv)
 {
-    atexit(doneCheck);
-    initialize( argc, argv );
+    atexit(done_check);
+    initialize(argc, argv);
 
     procState = PROC_STATE_LOAD_DEFS;
-    ag_scmStrings_init();
     readDefines();
 
     /*
@@ -79,19 +100,24 @@ inner_main( int argc, char** argv )
         tTemplate* pTF = loadTemplate(pzTemplFileName, NULL);
 
         procState = PROC_STATE_EMITTING;
-        processTemplate( pTF );
+        processTemplate(pTF);
 
         procState = PROC_STATE_CLEANUP;
-        cleanup( pTF );
+        cleanup(pTF);
     }
 
     procState = PROC_STATE_DONE;
-    signalSetup( SIG_DFL, SIG_DFL );
-    exit( EXIT_SUCCESS );
+    setup_signals(SIG_DFL, SIG_IGN, SIG_DFL);
+    exit_code = AUTOGEN_EXIT_SUCCESS;
+    done_check();
+    /* NOTREACHED */
 }
 
+/**
+ * main() called from _start()
+ */
 int
-main(int argc, char** argv)
+main(int argc, char ** argv)
 {
     optionSaveState(&autogenOptions);
     pfTrace = stderr;
@@ -101,59 +127,116 @@ main(int argc, char** argv)
      *  THEN you cannot capture the value portably.  So, the jumper has
      *  stashed it for use now.
      */
-    if (sigsetjmp( abendJumpEnv, 0 ) != 0)
-        signalExit( abendJumpSignal );
+    if (sigsetjmp(abendJumpEnv, 0) != 0)
+        cleanup_and_abort(abendJumpSignal);
 
-    signalSetup(ignoreSignal, abendSignal);
+    setup_signals(ignore_signal, SIG_DFL, catch_sig_and_bail);
 
-#if GUILE_VERSION >= 107000
-    if (getenv( "GUILE_WARN_DEPRECATED" ) == NULL)
-        putenv( (char*)(void*)"GUILE_WARN_DEPRECATED=no" );
-#endif
+    if (getenv("GUILE_WARN_DEPRECATED") == NULL)
+        putenv((char*)(void*)"GUILE_WARN_DEPRECATED=no");
+
+    AG_SCM_BOOT_GUILE(argc, argv, inner_main);
 
-    gh_enter( argc, argv, inner_main );
     /* NOT REACHED */
     return EXIT_FAILURE;
 }
 
+/**
+ *  This code must run regardless of which exit path is taken
+ */
 static void
-signalExit( int sig )
+exit_cleanup(wait_for_pclose_enum_t cl_wait)
 {
-    tSCC zErr[] = "AutoGen aborting on signal %d (%s) in state %s\n";
+    /*
+     *  There are contexts wherein this function can get run twice.
+     */
+    {
+        static int exit_cleanup_done = 0;
+        if (exit_cleanup_done) {
+            if (OPT_VALUE_TRACE > TRACE_NOTHING)
+                fprintf(pfTrace, "exit_cleanup re-done\n");
+            return;
+        }
+
+        exit_cleanup_done = 1;
+    }
+
+#ifdef SHELL_ENABLED
+    SCM_EVAL_CONST("(if (> (string-length shell-cleanup) 0)"
+                   " (shellf \"( (%s) & >/dev/null 2>&1 )\" shell-cleanup) )");
+#endif
+
+    close_server_shell();
+
+    if (OPT_VALUE_TRACE > TRACE_NOTHING)
+        fprintf(pfTrace, "exit_cleanup %s done\n",
+                (cl_wait == EXIT_PCLOSE_WAIT) ? "waited" : "no waiting");
+
+    do  {
+        if (pfTrace == stderr)
+            break;
+
+        if (! trace_is_to_pipe) {
+            fclose(pfTrace);
+            break;
+        }
+
+
+        fflush(pfTrace);
+        pclose(pfTrace);
+        if (cl_wait == EXIT_PCLOSE_WAIT) {
+            int status;
+            while (wait(&status) > 0)  ;
+        }
+    } while (0);
+
+    fflush(stdout);
+    fflush(stderr);
+}
+
+/**
+ *  A signal was caught, siglongjmp called and main() has called this.
+ *  We do not deallocate stuff so it can be found in the core dump.
+ */
+static void
+cleanup_and_abort(int sig)
+{
+    static char const zErr[] =
+        "AutoGen aborting on signal %d (%s) in state %s\n";
 
     if (*pzOopsPrefix != NUL) {
-        fputs( pzOopsPrefix, stderr );
+        fputs(pzOopsPrefix, stderr);
         pzOopsPrefix = zNil;
     }
 
-    fprintf( stderr, zErr, sig, strsignal( sig ),
-             ((unsigned)procState <= PROC_STATE_DONE)
-             ? apzStateName[ procState ] : "** BOGUS **" );
+    fprintf(stderr, zErr, sig, strsignal(sig),
+            ((unsigned)procState <= PROC_STATE_DONE)
+            ? state_names[ procState ] : "** BOGUS **");
 
-    fflush( stderr );
-    fflush( stdout );
-    if (pfTrace != stderr )
-        fflush( pfTrace );
-
-    if (procState == PROC_STATE_ABORTING)
-        _exit( sig + 128 );
+    if (procState == PROC_STATE_ABORTING) {
+        exit_cleanup(EXIT_PCLOSE_NOWAIT);
+        _exit(sig + 128);
+    }
 
     procState = PROC_STATE_ABORTING;
+    setup_signals(SIG_DFL, SIG_DFL, SIG_DFL);
 
     /*
      *  IF there is a current template, then we should report where we are
      *  so that the template writer knows where to look for their problem.
      */
     if (pCurTemplate != NULL) {
-        tSCC zAt[]  = "processing template %s\n"
-                      "            on line %d\n"
-                      "       for function %s (%d)\n";
+        static char const zAt[] =
+            "processing template %s\n"
+            "            on line %d\n"
+            "       for function %s (%d)\n";
+
         int line;
         teFuncType fnCd;
-        tCC* pzFn;
-        tCC* pzFl;
+        char const * pzFn;
+        char const * pzFl;
 
-        if ( pCurMacro == NULL ) {
+        if (pCurMacro == NULL) {
             pzFn = "pseudo-macro";
             line = 0;
             fnCd = -1;
@@ -169,90 +252,88 @@ signalExit( int sig )
         pzFl = pCurTemplate->pzTplFile;
         if (pzFl == NULL)
             pzFl = "NULL file name";
-        fprintf( stderr, zAt, pzFl, line, pzFn, fnCd );
+        fprintf(stderr, zAt, pzFl, line, pzFn, fnCd);
     }
 
-    signalSetup( SIG_DFL, SIG_DFL );
+#ifdef HAVE_SYS_RESOURCE_H
+    /*
+     *  If `--core' has been specified and if we have get/set rlimit,
+     *  then try to set the core limit to the "hard" maximum before aborting.
+     */
+    if (HAVE_OPT(CORE)) {
+        struct rlimit rlim;
+        getrlimit(RLIMIT_CORE, &rlim);
+        rlim.rlim_cur = rlim.rlim_max;
+        setrlimit(RLIMIT_CORE, &rlim);
+    }
+#endif
+
+    exit_cleanup(EXIT_PCLOSE_NOWAIT);
     abort();
 }
 
 
-/*
- *  abendSignal catches signals we abend on.  The "siglongjmp" goes back
- *  to the real "main()" procedure and it will call "signalExit()", above.
+/**
+ *  catch_sig_and_bail catches signals we abend on.  The "siglongjmp"
+ *  goes back to the real "main()" procedure and it will call
+ *  "cleanup_and_abort()", above.
  */
 static void
-abendSignal( int sig )
+catch_sig_and_bail(int sig)
 {
     switch (procState) {
-    case PROC_STATE_DONE:
     case PROC_STATE_ABORTING:
+        exit_code = AUTOGEN_EXIT_SIGNAL;
+
+    case PROC_STATE_DONE:
         break;
 
     default:
         abendJumpSignal = sig;
-        siglongjmp( abendJumpEnv, sig );
+        exit_code = AUTOGEN_EXIT_SIGNAL;
+        siglongjmp(abendJumpEnv, sig);
     }
 }
 
 
-/*
- *  ignoreSignal is the handler for SIGCHLD.  If we set it to default,
+/**
+ *  ignore_signal is the handler for SIGCHLD.  If we set it to default,
  *  it will kill us.  If we set it to ignore, it will be inherited.
  *  Therefore, always in all programs set it to call a procedure.
  *  The "wait(3)" call will do magical things, but will not override SIGIGN.
  */
 static void
-ignoreSignal( int sig )
+ignore_signal(int sig)
 {
-#ifdef DEBUG_ENABLED
-    fprintf( pfTrace, "Ignored signal %d (%s)\n", sig, strsignal( sig ));
-#endif
     return;
 }
 
 
-/*
- *  This is called during normal exit processing.
+/**
+ *  This is _always_ called for exit processing.
+ *  This only returns if "exit(3C)" is called during option processing.
+ *  We have no way of determining the correct exit code.
+ *  (Requested version or help exits EXIT_SUCCESS.  Option failures
+ *  are EXIT_FAILURE.  We cannot determine here.)
  */
 static void
-doneCheck( void )
+done_check(void)
 {
-    tSCC zErr[] =
+    static char const zErr[] =
         "Scheme evaluation error.  AutoGen ABEND-ing in template\n"
         "\t%s on line %d\n";
-#if GUILE_VERSION >= 107000
-    int exit_code = EXIT_SUCCESS;
-#endif
 
     /*
-     *  There are contexts wherein this function can get registered twice.
+     *  There are contexts wherein this function can get called twice.
      */
     {
-        static int doneCheckDone = 0;
-        if (doneCheckDone)
+        static int done_check_done = 0;
+        if (done_check_done) {
+            if (OPT_VALUE_TRACE > TRACE_NOTHING)
+                fprintf(pfTrace, "done_check re-done\n");
             return;
-        doneCheckDone = 1;
-    }
-
-#ifdef SHELL_ENABLED
-    ag_scm_c_eval_string_from_file_line(
-        "(if (> (string-length shell-cleanup) 0)"
-        " (shell shell-cleanup) )", __FILE__, __LINE__ - 1 );
-    closeServer();
-#endif
-
-    fflush( stdout );
-    fflush( stderr );
-
-    if (pfTrace != stderr ) {
-        if (trace_is_to_pipe) {
-            int status;
-
-            pclose( pfTrace );
-            while (wait( &status ) > 0)  ;
         }
-        else fclose( pfTrace );
+        done_check_done = 1;
     }
 
     switch (procState) {
@@ -267,122 +348,136 @@ doneCheck( void )
              *  Emit the CGI page header for an error message.  We will rewind
              *  stderr and write the contents to stdout momentarily.
              */
-            fputs( pzOopsPrefix, stdout );
+            fputs(pzOopsPrefix, stdout);
             pzOopsPrefix = zNil;
         }
 
         if (OPT_VALUE_TRACE > TRACE_NOTHING)
             scm_backtrace();
 
-        fprintf( stderr, zErr, pCurTemplate->pzTplFile, pCurMacro->lineNo );
+        fprintf(stderr, zErr, pCurTemplate->pzTplFile, pCurMacro->lineNo);
 
         /*
          *  We got here because someone called exit early.
          */
         do  {
 #ifndef DEBUG_ENABLED
-            closeOutput( AG_FALSE );
+            closeOutput(AG_FALSE);
 #else
-            closeOutput( AG_TRUE );
+            closeOutput(AG_TRUE);
 #endif
         } while (pCurFp->pPrev != NULL);
-
-#if GUILE_VERSION >= 107000
-        exit_code = EXIT_FAILURE;
-#endif
+        exit_code = AUTOGEN_EXIT_BAD_TEMPLATE;
         break; /* continue failure exit */
 
+    case PROC_STATE_LOAD_DEFS:
+        exit_code = AUTOGEN_EXIT_BAD_DEFINITIONS;
+        fprintf(stderr, "ABEND-ing in %s state\n", state_names[procState]);
+        goto autogen_aborts;
+
     default:
-        fprintf( stderr, "ABEND-ing in %s state\n", apzStateName[procState] );
-        /* FALLTHROUGH */
+        fprintf(stderr, "ABEND-ing in %s state\n", state_names[procState]);
+        goto autogen_aborts;
 
     case PROC_STATE_ABORTING:
+        exit_code = AUTOGEN_EXIT_BAD_TEMPLATE;
+
+    autogen_aborts:
         if (*pzOopsPrefix != NUL) {
             /*
              *  Emit the CGI page header for an error message.  We will rewind
              *  stderr and write the contents to stdout momentarily.
              */
-            fputs( pzOopsPrefix, stdout );
+            fputs(pzOopsPrefix, stdout);
             pzOopsPrefix = zNil;
         }
         break; /* continue failure exit */
 
     case PROC_STATE_OPTIONS:
         /* Exiting in option processing state is verbose enough */
+        break;
+
     case PROC_STATE_DONE:
         break; /* continue normal exit */
     }
 
     if (pzLastScheme != NULL) {
-        tSCC zGuileFail[] =
+        static char const fail_fmt[] =
             "Failing Guile command:  = = = = =\n\n%s\n\n"
             "=================================\n";
-        fprintf( stderr, zGuileFail, pzLastScheme );
+        fprintf(stderr, fail_fmt, pzLastScheme);
     }
 
     /*
      *  IF we diverted stderr, then now is the time to copy the text to stdout.
+     *  This is done for CGI mode wherein we produce an error page in case of
+     *  an error, but otherwise discard stderr.
      */
-    if (pzTmpStderr == NULL) {
-#if GUILE_VERSION >= 107000
-        if (exit_code != EXIT_SUCCESS)
-            _exit( exit_code );
-#endif
-        return;
+    if (cgi_stderr != NULL) {
+        do {
+            long pos = ftell(stderr);
+            char* pz;
+
+            /*
+             *  Don't bother with the overhead if there is no work to do.
+             */
+            if (pos <= 0)
+                break;
+            pz = AGALOC(pos, "stderr redirected text");
+            rewind(stderr);
+            fread( pz, (size_t)1, (size_t)pos, stderr);
+            fwrite(pz, (size_t)1, (size_t)pos, stdout);
+            AGFREE(pz);
+        } while (0);
+
+        unlink(cgi_stderr);
+        AGFREE(cgi_stderr);
+        cgi_stderr = NULL;
     }
 
-    do {
-        long pos = ftell( stderr );
-        char* pz;
+    ag_scribble_deinit();
 
-        /*
-         *  Don't bother with the overhead if there is no work to do.
-         */
-        if (pos <= 0)
-            break;
-        pz = AGALOC( pos, "stderr redirected text" );
-        rewind( stderr );
-        fread(  pz, (size_t)1, (size_t)pos, stderr );
-        fwrite( pz, (size_t)1, (size_t)pos, stdout );
-        AGFREE( pz );
-    } while (0);
+    if (OPT_VALUE_TRACE > TRACE_NOTHING)
+        fprintf(pfTrace, "done_check done\n");
 
-    fclose( stderr );
-    unlink( pzTmpStderr );
-    AGFREE( pzTmpStderr );
-    pzTmpStderr = NULL;
-#if GUILE_VERSION >= 107000
-    if (exit_code != EXIT_SUCCESS)
-        _exit( exit_code );
-#endif
+    exit_cleanup(EXIT_PCLOSE_WAIT);
+
+    /*
+     *  When processing options, return so that the option processing exit code
+     *  is used.  Otherwise, terminate execution now with the decided upon
+     *  exit code.  (Always EXIT_FAILURE, unless this was called at the end
+     *  of inner_main().)
+     */
+    if (procState != PROC_STATE_OPTIONS)
+        _exit(exit_code);
 }
 
 
 LOCAL void
-ag_abend_at( tCC* pzMsg
+ag_abend_at(char const * pzMsg
 #ifdef DEBUG_ENABLED
-    , tCC* pzFile, int line
+            , char const * pzFile, int line
 #endif
     )
 {
     if (*pzOopsPrefix != NUL) {
-        fputs( pzOopsPrefix, stderr );
+        fputs(pzOopsPrefix, stderr);
         pzOopsPrefix = zNil;
     }
 
 #ifdef DEBUG_ENABLED
-    fprintf( stderr, "Giving up in %s line %d\n", pzFile, line );
+    fprintf(stderr, "Giving up in %s line %d\n", pzFile, line);
 #endif
 
     if ((procState >= PROC_STATE_LIB_LOAD) && (pCurTemplate != NULL)) {
         int l_no = (pCurMacro == NULL) ? -1 : pCurMacro->lineNo;
-        fprintf( stderr, "Error in template %s, line %d\n\t",
-                 pCurTemplate->pzTplFile, l_no );
+        fprintf(stderr, "Error in template %s, line %d\n\t",
+                pCurTemplate->pzTplFile, l_no);
     }
-    fputs( pzMsg, stderr );
-    pzMsg += strlen( pzMsg );
+    fputs(pzMsg, stderr);
+    pzMsg += strlen(pzMsg);
     if (pzMsg[-1] != '\n')
-        fputc( '\n', stderr );
+        fputc('\n', stderr);
 
     {
         teProcState oldState = procState;
@@ -392,7 +487,7 @@ ag_abend_at( tCC* pzMsg
         case PROC_STATE_EMITTING:
         case PROC_STATE_INCLUDING:
         case PROC_STATE_CLEANUP:
-            longjmp( fileAbort, FAILURE );
+            longjmp(fileAbort, FAILURE);
             /* NOTREACHED */
         default:
             exit(EXIT_FAILURE);
@@ -403,8 +498,9 @@ ag_abend_at( tCC* pzMsg
 
 
 static void
-signalSetup( sighandler_proc_t* chldHandler,
-             sighandler_proc_t* dfltHandler )
+setup_signals(sighandler_proc_t * chldHandler,
+              sighandler_proc_t * abrtHandler,
+              sighandler_proc_t * dfltHandler)
 {
     struct sigaction  sa;
     int    sigNo  = 1;
@@ -415,7 +511,7 @@ signalSetup( sighandler_proc_t* chldHandler,
 #endif
 
     sa.sa_flags   = 0;
-    sigemptyset( &sa.sa_mask );
+    sigemptyset(&sa.sa_mask);
 
     do  {
         switch (sigNo) {
@@ -435,6 +531,10 @@ signalSetup( sighandler_proc_t* chldHandler,
             sa.sa_handler = chldHandler;
             break;
 
+        case SIGABRT:
+            sa.sa_handler = abrtHandler;
+            break;
+
             /*
              *  Signals we must leave alone.
              */
@@ -480,7 +580,7 @@ signalSetup( sighandler_proc_t* chldHandler,
 # error DAEMON-ization of AutoGen is not ready for prime time
   Choke Me.
         case SIGHUP:
-            if (HAVE_OPT( DAEMON )) {
+            if (HAVE_OPT(DAEMON)) {
                 sa.sa_handler = handleSighup;
                 break;
             }
@@ -490,7 +590,7 @@ signalSetup( sighandler_proc_t* chldHandler,
         default:
             sa.sa_handler = dfltHandler;
         }
-        sigaction( sigNo,  &sa, NULL );
+        sigaction(sigNo,  &sa, NULL);
     } while (++sigNo < maxSig);
 }
 
@@ -508,7 +608,7 @@ ao_malloc (size_t sz)
     void * res = malloc(sz);
     if (res == NULL) {
         fprintf(stderr, "malloc of %zd bytes failed\n", sz);
-        exit( EXIT_FAILURE );
+        exit(EXIT_FAILURE);
     }
     return res;
 }
@@ -517,10 +617,10 @@ ao_malloc (size_t sz)
 LOCAL void *
 ao_realloc (void *p, size_t sz)
 {
-    void * res = realloc(p, sz);
+    void * res = (p == NULL) ? malloc(sz) : realloc(p, sz);
     if (res == NULL) {
         fprintf(stderr, "realloc of %zd bytes at 0x%p failed\n", sz, p);
-        exit( EXIT_FAILURE );
+        exit(EXIT_FAILURE);
     }
     return res;
 }
@@ -540,11 +640,17 @@ ao_strdup (char const * str)
     char * res = strdup(str);
     if (res == NULL) {
         fprintf(stderr, "strdup of %d byte string failed\n", (int)strlen(str));
-        exit( EXIT_FAILURE );
+        exit(EXIT_FAILURE);
     }
     return res;
 }
 
+#ifdef __GNUC__
+    void ignore_vars(void);
+    void ignore_vars(void) {
+        (void)option_load_mode, (void)program_pkgdatadir;
+    }
+#endif
 /*
  * Local Variables:
  * mode: C
