@@ -2,12 +2,12 @@
 /*
  *  \file autogen.h
  *
- *  Time-stamp:        "2010-12-06 14:21:49 bkorb"
+ *  Time-stamp:        "2011-02-17 15:34:31 bkorb"
  *
  *  Global header file for AutoGen
  *
  *  This file is part of AutoGen.
- *  AutoGen Copyright (c) 1992-2010 by Bruce Korb - all rights reserved
+ *  AutoGen Copyright (c) 1992-2011 by Bruce Korb - all rights reserved
  *
  * AutoGen is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -31,7 +31,11 @@
 
 #include REGEX_HEADER
 #include <libguile/scmconfig.h>
-#include <guile/gh.h>
+#if GUILE_VERSION >= 109000
+# include <libguile.h>
+#else
+# include <guile/gh.h>
+#endif
 
 #include "opts.h"
 #include "expr.h"
@@ -39,6 +43,15 @@
 #include "directive.h"
 #include "snprintfv/printf.h"
 
+#define  LOG10_2to32  10  /* rounded up */
+
+#if defined(SHELL_ENABLED) || defined(DAEMON_ENABLED)
+#  ifndef HAVE_WORKING_FORK
+#    error SHELL is enabled and fork() does not work
+     choke me
+#  endif
+#endif
+
 #ifndef STR
 #  define _STR(s) #s
 #  define STR(s)  _STR(s)
@@ -52,6 +65,14 @@
 #  define MODE extern
 #endif
 
+#ifndef DIRCH
+# if defined(_WIN32) && !defined(__CYGWIN__)
+#  define DIRCH                  '\\'
+# else
+#  define DIRCH                  '/'
+# endif
+#endif
+
 #define YYSTYPE t_word
 
 #define ag_offsetof(TYPE, MEMBER) ((unsigned long) &((TYPE *)0)->MEMBER)
@@ -177,29 +198,29 @@ struct template_lib_marker {
 #define EMIT_NO_DEFINE      0x0800  /* don't get defined value */
 
 struct macro_desc {
-    teFuncType  funcCode;  /* Macro function         */
-    int         lineNo;    /* of macro def           */
-    int         endIndex;  /* End of block macro     */
-    int         sibIndex;  /* Sibling macro (ELIF or SELECT) */
+    teFuncType    funcCode;    /* Macro function           */
+    int           lineNo;      /* of macro def             */
+    int           endIndex;    /* End of block macro       */
+    int           sibIndex;    /* Sibling macro (ELIF or SELECT) */
 
-    uintptr_t   ozName;    /* macro name (sometimes) */
-    uintptr_t   ozText;    /* associated text        */
-    uintptr_t   res;       /* some sort of result    */
-    void*       funcPrivate;
+    uintptr_t     ozName;      /* macro name (sometimes)   */
+    uintptr_t     ozText;      /* associated text          */
+    uintptr_t     res;         /* some sort of result      */
+    void *        funcPrivate;
 };
 
 struct template_desc {
-    tTlibMark   magic;       /* TEMPLATE_MAGIC_MARKER    */
-    size_t      descSize;    /* Structure Size           */
-    char*       pNext;       /* Next Pointer             */
-    int         macroCt;     /* Count of Macros          */
-    tCC*        pzTplFile;   /* Name of template file    */
-    char*       pzTplName;   /* Defined Macro Name       */
-    char*       pzTemplText; /* offset of the text       */
-    char        zStartMac[MAX_SUFFIX_LEN];
-    char        zEndMac[MAX_SUFFIX_LEN];
-    tMacro      aMacros[1];  /* Array of Macros          */
-/*  char        text[...];    * strings at end of macros */
+    tTlibMark     magic;       /* TEMPLATE_MAGIC_MARKER    */
+    size_t        descSize;    /* Structure Size           */
+    char *        pNext;       /* Next Pointer             */
+    int           macroCt;     /* Count of Macros          */
+    char const *  pzTplFile;   /* Name of template file    */
+    char *        pzTplName;   /* Defined Macro Name       */
+    char *        pzTemplText; /* offset of the text       */
+    char          zStartMac[MAX_SUFFIX_LEN];
+    char          zEndMac[MAX_SUFFIX_LEN];
+    tMacro        aMacros[1];  /* Array of Macros          */
+/*  char          text[...];    * strings at end of macros */
 };
 
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
@@ -240,11 +261,11 @@ struct defEntry {
 };
 
 struct scanContext {
-    tScanCtx*   pCtx;
-    char*       pzScan;
-    tCC*        pzCtxFname;
-    char*       pzData;
-    int         lineNo;
+    tScanCtx *    pCtx;
+    char*         pzScan;
+    char const *  pzCtxFname;
+    char *        pzData;
+    int           lineNo;
 };
 
 struct outSpec {
@@ -329,7 +350,7 @@ MODE char const *   pzOopsPrefix     VALUE( "" );
 /*
  *  Template Processing Globals
  */
-MODE tCC*           pzCurSfx         VALUE( NULL );
+MODE char const *   pzCurSfx         VALUE( NULL );
 /**
  * The time to set for the modification times of the output files.
  */
@@ -345,6 +366,14 @@ MODE char *         pzCurStart       VALUE( NULL );
 MODE uintptr_t      curStartOff      VALUE( 0 );
 MODE tForInfo       forInfo          VALUE( { 0 } );
 MODE FILE *         pfTrace          VALUE( NULL );
+/**
+ * temporary file name template
+ */
+MODE char const *   pz_temp_tpl      VALUE( NULL );
+/**
+ * Length of the template that is the temp directory
+ */
+MODE size_t         temp_tpl_dir_len VALUE( 0 );
 /**
  * dependency file file pointer.
  */
@@ -441,26 +470,30 @@ MODE tDefEntry *    pCurrentEntry    VALUE( NULL );
 
 MODE tpChar         pCurDir          VALUE( NULL );
 
+MODE autogen_exit_code_t exit_code   VALUE( AUTOGEN_EXIT_OPTION_ERROR );
+
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  *
  *  GLOBAL STRINGS
  */
 #define MKSTRING(_n, _v) \
-        MODE char const z ## _n[sizeof(_v)] VALUE(_v)
+        MODE char const _n[sizeof(_v)] VALUE(_v)
 
-MKSTRING(AllocErr,   "Allocation Failure");
-MKSTRING(AllocWhat,  "Could not allocate a %d byte %s\n");
-MKSTRING(Cannot,     "fserr %d: cannot %s %s:  %s\n");
-MKSTRING(DevNull,    "/dev/null");
-MKSTRING(Empty,      "");
-MKSTRING(FileFormat, "%s%s\0%s.%s");
-MKSTRING(FileLine,   "\tfrom %s line %d\n");
-MKSTRING(Format,     "format");
-MKSTRING(MemFile,    "in-mem file");
-MKSTRING(Nil,        "");
-MKSTRING(NotStr,     "ERROR: %s is not a string\n");
-MKSTRING(ShDone,     "ShElL-OuTpUt-HaS-bEeN-cOmPlEtEd");
-MKSTRING(TplWarn,    "Warning in template %s, line %d\n\t%s\n");
+MKSTRING(zAllocErr,   "Allocation Failure");
+MKSTRING(zAllocWhat,  "Could not allocate a %d byte %s\n");
+MKSTRING(zCannot,     "fserr %d: cannot %s %s:  %s\n");
+MKSTRING(zDevNull,    "/dev/null");
+MKSTRING(zEmpty,      "");
+MKSTRING(zFileFormat, "%s%s\0%s.%s");
+MKSTRING(zFileLine,   "\tfrom %s line %d\n");
+MKSTRING(zFormat,     "format");
+MKSTRING(zMemFile,    "in-mem file");
+MKSTRING(zNil,        "");
+MKSTRING(zNotStr,     "ERROR: %s is not a string\n");
+MKSTRING(zShDone,     "ShElL-OuTpUt-HaS-bEeN-cOmPlEtEd");
+MKSTRING(zTplWarn,    "Warning in template %s, line %d\n\t%s\n");
+
+#undef MKSTRING
 
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  *
@@ -513,96 +546,7 @@ MODE v2c_t p2p VALUE( { NULL } );
 /*
  *  Code variations based on the version of Guile:
  */
-#if GUILE_VERSION < 107000  /* pre-Guile 1.7.x */
-
-#if GUILE_VERSION < 106000 /* Guile 1.4 */
-
-#   define AG_SCM_STRING_P(_s)          gh_string_p(_s)
-#   define AG_SCM_BOOL_P(_b)            gh_boolean_p(_b)
-#   define AG_SCM_SYM_P(_s)             gh_symbol_p(_s)
-#   define AG_SCM_IS_PROC(_p)           gh_procedure_p(_p)
-#   define AG_SCM_CHAR_P(_c)            gh_char_p(_c)
-#   define AG_SCM_VEC_P(_v)             gh_vector_p(_v)
-#   define AG_SCM_PAIR_P(_p)            gh_pair_p(_p)
-#   define AG_SCM_NUM_P(_n)             gh_number_p(_n)
-#   define AG_SCM_LIST_P(_l)            gh_list_p(_l)
-#   define AG_SCM_STR2SCM(_st,_sz)      gh_str2scm(_st,_sz)
-#   define AG_SCM_STR02SCM(_s)          gh_str02scm(_s)
-
-#else /* Guile 1.6.x */
-
-#   define AG_SCM_STRING_P(_s)          SCM_STRINGP(_s)
-#   define AG_SCM_BOOL_P(_b)            SCM_BOOLP(_b)
-#   define AG_SCM_SYM_P(_s)             SCM_SYMBOLP(_s)
-#   define AG_SCM_IS_PROC(_p)           SCM_NFALSEP( scm_procedure_p(_p))
-#   define AG_SCM_CHAR_P(_c)            SCM_CHARP(_c)
-#   define AG_SCM_VEC_P(_v)             SCM_VECTORP(_v)
-#   define AG_SCM_PAIR_P(_p)            SCM_NFALSEP( scm_pair_p(_p))
-#   define AG_SCM_NUM_P(_n)             SCM_NUMBERP(_n)
-#   define AG_SCM_LIST_P(_l)            SCM_NFALSEP( scm_list_p(_l))
-#   define AG_SCM_STR2SCM(_st,_sz)      scm_mem2string(_st,_sz)
-#   define AG_SCM_STR02SCM(_s)          scm_makfrom0str(_s)
-#endif
-
-  static inline char* ag_scm2zchars(SCM s, tCC* type)
-  {
-    if (! AG_SCM_STRING_P(s))
-        AG_ABEND(aprf(zNotStr, type));
-
-    if (SCM_SUBSTRP(s))
-        s = scm_makfromstr(SCM_CHARS(s), SCM_LENGTH(s), 0);
-    return SCM_CHARS(s);
-  }
-
-# define AG_SCM_STRLEN(_s)              SCM_LENGTH(_s)
-# define AG_SCM_CHARS(_s)               SCM_CHARS(_s)
-
-#else /* Guile 1.7 and following */
-
-  extern char* ag_scm2zchars(SCM s, tCC* type);
-
-# if GUILE_VERSION < 108000
-#   define AG_SCM_STRLEN(_s)            SCM_STRING_LENGTH(_s)
-#   define AG_SCM_CHARS(_s)             SCM_STRING_CHARS(_s)
-#   define AG_SCM_VEC_P(_v)             SCM_VECTORP(_v)
-# else
-#   define AG_SCM_STRLEN(_s)            scm_c_string_length(_s)
-#   define AG_SCM_CHARS(_s)             scm_i_string_chars(_s)
-#   define AG_SCM_VEC_P(_v)             scm_is_vector(_v)
-# endif
-
-# define AG_SCM_STRING_P(_s)            scm_is_string(_s)
-# define AG_SCM_BOOL_P(_b)              SCM_BOOLP(_b)
-# define AG_SCM_SYM_P(_s)               SCM_SYMBOLP(_s)
-# define AG_SCM_IS_PROC(_p)             scm_is_true( scm_procedure_p(_p))
-# define AG_SCM_CHAR_P(_c)              SCM_CHARP(_c)
-# define AG_SCM_PAIR_P(_p)              scm_is_true( scm_pair_p(_p))
-# define AG_SCM_NUM_P(_n)               scm_is_number(_n)
-# define AG_SCM_LIST_P(_l)              SCM_NFALSEP( scm_list_p(_l))
-# define AG_SCM_STR2SCM(_st,_sz)        scm_from_locale_stringn(_st,_sz)
-# define AG_SCM_STR02SCM(_s)            scm_from_locale_string(_s)
-#endif /* pre-1.7 / 1.7 and following */
-
-/*
- *  Guile version invariant!!
- */
-#define AG_SCM_INT2SCM(_i)              gh_int2scm(_i)
-#define AG_SCM_SCM2INT(_i)              gh_scm2int(_i)
-#define AG_SCM_LONG2SCM(_i)             gh_long2scm(_i)
-#define AG_SCM_SCM2LONG(_i)             gh_scm2long(_i)
-
-static inline SCM ag_eval(tCC* pzStr)
-{
-    SCM res;
-    tCC* pzSaveScheme = pzLastScheme; /* Watch for nested calls */
-    pzLastScheme = pzStr;
-
-    res = ag_scm_c_eval_string_from_file_line(
-        pzStr, pCurTemplate->pzTplFile, pCurMacro->lineNo);
-
-    pzLastScheme = pzSaveScheme;
-    return res;
-}
+#include "guile-iface.h"
 
 #endif /* AUTOGEN_BUILD */
 /*
