@@ -2,13 +2,13 @@
 /**
  *  \file expGuile.c
  *
- *  Time-stamp:        "2010-07-10 16:29:48 bkorb"
+ *  Time-stamp:        "2011-01-20 16:14:27 bkorb"
  *
  *  This module implements the expression functions that should
  *  be part of Guile.
  *
  *  This file is part of AutoGen.
- *  AutoGen Copyright (c) 1992-2010 by Bruce Korb - all rights reserved
+ *  AutoGen Copyright (c) 1992-2011 by Bruce Korb - all rights reserved
  *
  * AutoGen is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -25,7 +25,7 @@
  */
 
 LOCAL teGuileType
-gh_type_e(SCM typ)
+ag_scm_type_e(SCM typ)
 {
     if (AG_SCM_BOOL_P(  typ)) return GH_TYPE_BOOLEAN;
     if (AG_SCM_SYM_P(   typ)) return GH_TYPE_SYMBOL;
@@ -42,7 +42,8 @@ gh_type_e(SCM typ)
 
 
 LOCAL SCM
-ag_scm_c_eval_string_from_file_line(tCC* pzExpr, tCC* pzFile, int line)
+ag_scm_c_eval_string_from_file_line(
+    char const * pzExpr, char const * pzFile, int line)
 {
     SCM port;
 
@@ -53,7 +54,7 @@ ag_scm_c_eval_string_from_file_line(tCC* pzExpr, tCC* pzFile, int line)
 
 #if GUILE_VERSION < 106000
     {
-        tSCC zEx[] = "eval-string-from-file-line";
+        static char const zEx[] = "eval-string-from-file-line";
         SCM  expr  = scm_makfrom0str(pzExpr);
         port = scm_mkstrport(SCM_INUM0, expr, SCM_OPN | SCM_RDNG, zEx);
     }
@@ -147,7 +148,7 @@ ag_scm_max(SCM list)
         car  = SCM_CAR(list);
         list = SCM_CDR(list);
 
-        switch (gh_type_e(car)) {
+        switch (ag_scm_type_e(car)) {
         case GH_TYPE_BOOLEAN:
             if (car == SCM_BOOL_F) {
                 val = 0;
@@ -157,11 +158,11 @@ ag_scm_max(SCM list)
             break;
 
         case GH_TYPE_CHAR:
-            val = (int)gh_scm2char(car);
+            val = (int)AG_SCM_CHAR(car);
             break;
 
         case GH_TYPE_NUMBER:
-            val = gh_scm2long(car);
+            val = AG_SCM_TO_LONG(car);
             break;
 
         case GH_TYPE_STRING:
@@ -174,7 +175,7 @@ ag_scm_max(SCM list)
         max_val = MAX(max_val, val);
     }
 
-    return gh_long2scm(max_val);
+    return AG_SCM_FROM_LONG(max_val);
 }
 
 
@@ -206,7 +207,7 @@ ag_scm_min(SCM list)
         car  = SCM_CAR(list);
         list = SCM_CDR(list);
 
-        switch (gh_type_e(car)) {
+        switch (ag_scm_type_e(car)) {
         case GH_TYPE_BOOLEAN:
             if (car == SCM_BOOL_F) {
                 val = 0;
@@ -216,11 +217,11 @@ ag_scm_min(SCM list)
             break;
 
         case GH_TYPE_CHAR:
-            val = (int)gh_scm2char(car);
+            val = (int)AG_SCM_CHAR(car);
             break;
 
         case GH_TYPE_NUMBER:
-            val = gh_scm2long(car);
+            val = AG_SCM_TO_LONG(car);
             break;
 
         case GH_TYPE_STRING:
@@ -233,7 +234,7 @@ ag_scm_min(SCM list)
         min_val = MIN(min_val, val);
     }
 
-    return gh_long2scm(min_val);
+    return AG_SCM_FROM_LONG(min_val);
 }
 
 
@@ -258,16 +259,16 @@ ag_scm_sum(SCM list)
     do  {
         SCM  car = SCM_CAR(list);
         list = SCM_CDR(list);
-        switch (gh_type_e(car)) {
+        switch (ag_scm_type_e(car)) {
         default:
             return SCM_UNDEFINED;
 
         case GH_TYPE_CHAR:
-            sum += (long)(unsigned char)gh_scm2char(car);
+            sum += (long)(unsigned char)AG_SCM_CHAR(car);
             break;
 
         case GH_TYPE_NUMBER:
-            sum += gh_scm2long(car);
+            sum += AG_SCM_TO_LONG(car);
             break;
 
         case GH_TYPE_STRING:
@@ -275,7 +276,7 @@ ag_scm_sum(SCM list)
         }
     } while (--len > 0);
 
-    return gh_long2scm(sum);
+    return AG_SCM_FROM_LONG(sum);
 }
 
 
@@ -293,8 +294,8 @@ ag_scm_sum(SCM list)
 SCM
 ag_scm_string_to_c_name_x(SCM str)
 {
-    tSCC  zFun[] = "ag_scm_string_to_c_name_x";
-    tSCC  zMap[] = "cannot map unprintable chars to C name chars";
+    static char const zFun[] = "ag_scm_string_to_c_name_x";
+    static char const zMap[] = "cannot map unprintable chars to C name chars";
     int   len;
     char* pz;
 
