@@ -1,12 +1,12 @@
 
 /*
  *
- *  Time-stamp:        "2010-07-03 09:49:59 bkorb"
+ *  Time-stamp:        "2011-01-27 12:36:37 bkorb"
  *
  *  This module implements the FOR text macro.
  *
  *  This file is part of AutoGen.
- *  AutoGen Copyright (c) 1992-2010 by Bruce Korb - all rights reserved
+ *  AutoGen Copyright (c) 1992-2011 by Bruce Korb - all rights reserved
  *
  * AutoGen is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -23,10 +23,11 @@
  */
 
 #define ENTRY_END  INT_MAX
+#define UNASSIGNED 0x7BAD0BAD
 
 static tForState*  pFS;  /* Current "FOR" information (state) */
 
-tSCC zNoEnd[] = "%s ERROR:  FOR loop `%s' does not end\n";
+static char const zNoEnd[] = "%s ERROR:  FOR loop `%s' does not end\n";
 
 /* = = = START-STATIC-FORWARD = = = */
 static ag_bool
@@ -39,7 +40,7 @@ static int
 doForEach(tTemplate * pT, tMacro * pMac, tDefEntry * pFoundDef);
 
 static void
-load_ForIn(tCC* pzSrc, size_t srcLen, tTemplate* pT, tMacro* pMac);
+load_ForIn(char const * pzSrc, size_t srcLen, tTemplate* pT, tMacro* pMac);
 /* = = = END-STATIC-FORWARD = = = */
 
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
@@ -172,7 +173,7 @@ ag_scm_for_from(SCM from)
 {
     if ((! pFS->for_loading) || (! AG_SCM_NUM_P(from)))
         return SCM_UNDEFINED;
-    pFS->for_from = AG_SCM_SCM2INT(from);
+    pFS->for_from = AG_SCM_TO_INT(from);
     return SCM_BOOL_T;
 }
 
@@ -192,7 +193,7 @@ ag_scm_for_to(SCM to)
 {
     if ((! pFS->for_loading) || (! AG_SCM_NUM_P(to)))
         return SCM_UNDEFINED;
-    pFS->for_to = AG_SCM_SCM2INT(to);
+    pFS->for_to = AG_SCM_TO_INT(to);
     return SCM_BOOL_T;
 }
 
@@ -212,7 +213,7 @@ ag_scm_for_by(SCM by)
 {
     if ((! pFS->for_loading) || (! AG_SCM_NUM_P(by)))
         return SCM_UNDEFINED;
-    pFS->for_by = AG_SCM_SCM2INT(by);
+    pFS->for_by = AG_SCM_TO_INT(by);
     return SCM_BOOL_T;
 }
 
@@ -312,10 +313,10 @@ doForByStep(tTemplate* pT, tMacro* pMac, tDefEntry * pFoundDef)
         tDefEntry* pLast = (pFoundDef->pEndTwin != NULL)
                            ? pFoundDef->pEndTwin : pFoundDef;
 
-        if (pFS->for_from == 0x7BAD0BAD)
+        if (pFS->for_from == UNASSIGNED)
             pFS->for_from = (invert) ? pLast->index : pFoundDef->index;
 
-        if (pFS->for_to == 0x7BAD0BAD)
+        if (pFS->for_to == UNASSIGNED)
             pFS->for_to = (invert) ? pFoundDef->index : pLast->index;
 
         /*
@@ -483,7 +484,7 @@ doForEach(tTemplate * pT, tMacro * pMac, tDefEntry * pFoundDef)
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 static void
-load_ForIn(tCC* pzSrc, size_t srcLen, tTemplate* pT, tMacro* pMac)
+load_ForIn(char const * pzSrc, size_t srcLen, tTemplate* pT, tMacro* pMac)
 {
     char* pzName = pT->pzTemplText + pMac->ozName;
     int   ix     = 0;
@@ -731,7 +732,7 @@ mFunc_For(tTemplate* pT, tMacro* pMac)
      */
     if (pT->pzTemplText[ pMac->ozText ] == '(') {
         pFS->for_from  = \
-        pFS->for_to    = 0x7BAD0BAD;
+        pFS->for_to    = UNASSIGNED;
 
         pFS->for_loading = AG_TRUE;
         (void) eval(pT->pzTemplText + pMac->ozText);
@@ -761,17 +762,17 @@ mFunc_For(tTemplate* pT, tMacro* pMac)
 
 
 tMacro*
-mLoad_For(tTemplate* pT, tMacro* pMac, tCC** ppzScan)
+mLoad_For(tTemplate* pT, tMacro* pMac, char const ** ppzScan)
 {
-    char*   pzCopy = pT->pNext; /* next text dest   */
-    tCC*    pzSrc  = (char const*)pMac->ozText; /* macro text */
-    size_t  srcLen = (size_t)pMac->res;         /* macro len  */
-    tMacro* pEndMac;
+    char *        pzCopy = pT->pNext; /* next text dest   */
+    char const *  pzSrc  = (char const*)pMac->ozText; /* macro text */
+    size_t        srcLen = (size_t)pMac->res;         /* macro len  */
+    tMacro *      pEndMac;
 
     /*
      *  Save the global macro loading mode
      */
-    tpLoadProc* papLP = papLoadProc;
+    tpLoadProc const * papLP = papLoadProc;
 
     static tpLoadProc apForLoad[ FUNC_CT ] = { NULL };
 
