@@ -1,14 +1,14 @@
 
 /*
- *  columns.c
- *  $Id: 4c61808f04105af6eb01ca5bfd13678cd6754969 $
- *  Time-stamp:        "2010-02-24 08:39:31 bkorb"
+ *  \file columns.c
  *
- *  Columns Copyright (c) 1992-2010 by Bruce Korb - all rights reserved
+ *  Time-stamp:        "2011-01-02 17:03:44 bkorb"
+ *
+ *  Columns Copyright (c) 1992-2011 by Bruce Korb - all rights reserved
  *  Columns is free software.
  *  This file is part of AutoGen.
  *
- *  AutoGen copyright (c) 1992-2009 by Bruce Korb - all rights reserved
+ *  AutoGen copyright (c) 1992-2011 by Bruce Korb - all rights reserved
  *
  *  AutoGen is free software: you can redistribute it and/or modify it
  *  under the terms of the GNU General Public License as published by the
@@ -41,14 +41,14 @@ int fillColumnCt  = 0;
 char zLine[ LINE_LIMIT ];
 char zFmtLine[ LINE_LIMIT ];
 
-char**  papzLines  = (char**)NULL;
-tCC*    pzLinePfx  = NULL;
-tCC*    pzFirstPfx = NULL;
-size_t  allocCt    = 0;
-size_t  usedCt     = 0;
-size_t  columnCt   = 0;
-size_t  columnSz   = 0;
-size_t  indentSize = 0;
+char**       papzLines  = (char**)NULL;
+char const * pzLinePfx  = "";
+char const * pzFirstPfx = NULL;
+size_t       allocCt    = 0;
+size_t       usedCt     = 0;
+size_t       columnCt   = 0;
+size_t       columnSz   = 0;
+size_t       indentSize = 0;
 
 /* = = = START-STATIC-FORWARD = = = */
 static void
@@ -57,26 +57,32 @@ fserr_die(char const * fmt, ...);
 static inline void *
 malloc_or_die(size_t sz);
 
+static char const *
+construct_first_pfx(char const * f_indent);
+
 static uint32_t
-handleIndent( tCC* pzIndentArg );
+pad_indentation(char const * pzIndentArg, char const ** pfx);
 
 static void
 readLines(void);
 
 static void
-writeColumns( void );
+writeColumns(void);
 
 static void
-writeRows( void );
+trim_last_separation(void);
+
+static void
+writeRows(void);
 
 static int
 emitWord(char const * word, size_t len, int col);
 
 static void
-writeFill( void );
+writeFill(void);
 
 static int
-compProc( const void* p1, const void* p2 );
+compProc(const void * p1, const void * p2);
 /* = = = END-STATIC-FORWARD = = = */
 
 int
@@ -85,43 +91,12 @@ main(int argc, char ** argv)
     (void)optionProcess( &columnsOptions, argc, argv );
 
     if (HAVE_OPT( INDENT )) {
-        indentSize = handleIndent( OPT_ARG( INDENT ));
+        indentSize = pad_indentation( OPT_ARG(INDENT), &pzLinePfx);
         OPT_VALUE_WIDTH -= indentSize;
 
-        if (! HAVE_OPT( FIRST_INDENT ))
-            pzFirstPfx = pzLinePfx;
-        else {
-
-            /*
-             *  The first line has a special indentation/prefix.
-             *  Compute it, but do not let it be larger than
-             *  the indentation value.
-             */
-            tCC* pzSave = pzLinePfx;
-            size_t firstSize = handleIndent( OPT_ARG( FIRST_INDENT ));
-            pzFirstPfx = pzLinePfx;
-            pzLinePfx  = pzSave;
-
-            /*
-             *  Now force the first line prefix to have the same size
-             *  as the indentSize
-             */
-            if (firstSize > indentSize) {
-                static char const zSepLine[] =
-                    "Note: prefix `%s' has been put on a separate line\n";
-                fputs(pzFirstPfx, stdout);
-                putc('\n', stdout);
-                fprintf( stderr, zSepLine, pzFirstPfx );
-                pzFirstPfx = pzLinePfx;
-
-            } else if (firstSize < indentSize) {
-                char* tmp = malloc_or_die( indentSize + 1 );
-                char  z[10];
-                snprintf( z, sizeof(z), "%%-%ds", (int)indentSize );
-                snprintf( tmp, indentSize + 1, z, pzFirstPfx );
-                pzFirstPfx = tmp;
-            }
-        }
+        pzFirstPfx = HAVE_OPT(FIRST_INDENT)
+            ? construct_first_pfx( OPT_ARG(FIRST_INDENT))
+            : pzLinePfx;
     }
 
     if (HAVE_OPT( LINE_SEPARATION ))
@@ -174,23 +149,65 @@ malloc_or_die(size_t sz)
     return res;
 }
 
+static char const *
+construct_first_pfx(char const * f_indent)
+{
+    static char const pad_fmt[] = "%%-%ds";
+    // 24 > log10(0xFFFFFFFFFFFFFFFFULL)
+    char pfx_buf[24 + sizeof(pad_fmt)];
+    size_t firstSize = pad_indentation(f_indent, &pzFirstPfx);
+    size_t len;
+    char * res;
+
+    /*
+     *  If this first line exceeds the indentation size, then we
+     *  need to append a newline and any indentation.
+     */
+    if (firstSize > indentSize) {
+        size_t sep_len = HAVE_OPT(LINE_SEPARATION)
+            ? strlen( OPT_ARG(LINE_SEPARATION)) : 0;
+        len = firstSize + sep_len + indentSize + 3;
+        sprintf(pfx_buf, pad_fmt, (int)firstSize);
+    } else {
+        len = indentSize + 3;
+        sprintf(pfx_buf, pad_fmt, (int)indentSize);
+    }
+
+    res = malloc_or_die(len);
+    snprintf(res, len, pfx_buf, pzFirstPfx);
+    pzFirstPfx = res;
+
+    if (firstSize > indentSize) {
+        char * p = res + firstSize;
+
+        if (HAVE_OPT( LINE_SEPARATION )) {
+            len = strlen(OPT_ARG(LINE_SEPARATION));
+            memcpy(p, OPT_ARG(LINE_SEPARATION), len);
+            p  += len;
+        }
+
+        sprintf(p, "\n%s", pzLinePfx);
+    }
+
+    return res;
+}
 
 static uint32_t
-handleIndent( tCC* pzIndentArg )
+pad_indentation(char const * pzIndentArg, char const ** pfx)
 {
-    char* pz;
+    char * pz;
     unsigned int colCt = (unsigned int)strtoul(pzIndentArg, &pz, 0);
 
     /*
      *  IF the indent argument is a number
      */
     if ((*pz == NUL) && (colCt > 0) && (colCt < OPT_VALUE_WIDTH)) {
-        char* p;
+        char * p;
 
         /*
          *  Allocate a string to hold the line prefix
          */
-        pzLinePfx = p = malloc_or_die( (size_t)colCt + 1 );
+        *pfx = p = malloc_or_die( (size_t)colCt + 1 );
 
         /*
          *  Set it to a NUL terminated string of spaces
@@ -199,20 +216,18 @@ handleIndent( tCC* pzIndentArg )
         p[colCt] = NUL;
 
     } else {
-        tCC* p;
         /*
          *  Otherwise, set the line prefix to whatever the string is.
          *  It will not be the empty string because that is handled
          *  as an indent count of zero and is ignored.
          */
-        pzLinePfx = pzIndentArg;
-        p = pzIndentArg;
-        colCt =  0;
+        char const * p = pzIndentArg;
+        *pfx = pzIndentArg;
+        colCt     =  0;
+
         for (;;) {
             /*
-             *  Figure out how much of the line is taken up by
-             *  the prefix.  We might consider restricted format
-             *  strings some time in the future, but not now.
+             *  Compute the length of the last line of the prefix.
              */
             switch (*p++) {
             case NUL:
@@ -248,8 +263,8 @@ readLines(void)
 {
     int   sepLen;
 
-    if (HAVE_OPT( SEPARATION ))
-         sepLen = strlen( OPT_ARG( SEPARATION ));
+    if (HAVE_OPT(SEPARATION))
+         sepLen = strlen(OPT_ARG(SEPARATION));
     else sepLen = 0;
 
 
@@ -314,7 +329,7 @@ readLines(void)
          *  the entries may get reordered.
          */
         if (sepLen > 0)
-            strcat( pzL, OPT_ARG(SEPARATION));
+            strcat(pzL, OPT_ARG(SEPARATION));
 
         if (len > maxEntryWidth)
             maxEntryWidth = len;
@@ -397,7 +412,7 @@ readLines(void)
 
 
 static void
-writeColumns( void )
+writeColumns(void)
 {
     char zFmt[ 12 ];
     int  colCt, rowCt, col, row;
@@ -493,10 +508,9 @@ writeColumns( void )
          *  FOR every column except the last,
          *     print the entry with the width format
          *
-         *  No need to worry about referring to a non-existent
-         *  entry.  Only the last column might have that problem,
-         *  and we addressed it above where the column count got
-         *  decremented.
+         *  No need to worry about referring to a non-existent entry.  Only
+         *  the last column might have that problem, and we addressed it above
+         *  where the column count got decremented.
          */
         while (++col < colCt) {
             pzL = *(pPL[col-1].papz++);
@@ -505,9 +519,8 @@ writeColumns( void )
         }
 
         /*
-         *  See if we are on the last row.  If so, then
-         *  this is the last entry.  Strip any separation
-         *  characters, emit the entry and break out.
+         *  See if we are on the last row. If so, then this is the last entry.
+         *  Strip any separation characters, emit the entry and break out.
          */
         if (++row == rowCt) {
             /*
@@ -516,10 +529,14 @@ writeColumns( void )
              */
             if (HAVE_OPT( SEPARATION )) {
                 char* pz = pzE + strlen( pzE )
-                         - strlen( OPT_ARG( SEPARATION ));
+                         - strlen( OPT_ARG(SEPARATION));
                 *pz = NUL;
             }
-            fputs( pzE, stdout );
+
+            fputs(pzE, stdout);
+            if (HAVE_OPT(ENDING))
+                fputs(OPT_ARG(ENDING), stdout);
+
             putc( '\n', stdout );
             break;
         }
@@ -540,25 +557,25 @@ writeColumns( void )
     free(pPL);
 }
 
+static void
+trim_last_separation(void)
+{
+    char* pz = papzLines[ usedCt-1 ];
+    pz += strlen(pz) - strlen( OPT_ARG(SEPARATION));
+    *pz = NUL;
+}
 
 static void
-writeRows( void )
+writeRows(void)
 {
-    char zFmt[ 12 ];
+    char zFmt[32];
     int  colCt;
 
     colCt = columnCt;
     snprintf(zFmt, sizeof(zFmt), "%%-%ds", (int)columnSz);
 
-    /*
-     *  IF we have a separator,
-     *  THEN remove it from the last entry.
-     */
-    if (HAVE_OPT( SEPARATION )) {
-        char* pz = papzLines[ usedCt-1 ];
-        pz += strlen( pz ) - strlen( OPT_ARG( SEPARATION ));
-        *pz = NUL;
-    }
+    if (HAVE_OPT( SEPARATION ))
+        trim_last_separation();
 
     if (pzFirstPfx != NULL) {
         fputs( pzFirstPfx, stdout );
@@ -581,9 +598,12 @@ writeRows( void )
              *  THEN emit it and a new line and break out
              */
             if (--left <= 0) {
-                fputs( pzL, stdout );
-                putc( '\n', stdout );
-                free( (void*)pzL );
+                fputs(pzL, stdout);
+                if (HAVE_OPT(ENDING))
+                    fputs(OPT_ARG(ENDING), stdout);
+
+                putc('\n', stdout);
+                free((void*)pzL);
                 break;
             }
 
@@ -651,14 +671,20 @@ emitWord(char const * word, size_t len, int col)
     return col;
 }
 
-
+/*
+ *  writeFill -- fill the output.  Pack together as much as will fit
+ *  on each line.
+ */
 static void
-writeFill( void )
+writeFill(void)
 {
     char**  ppzLL = papzLines;
     size_t  left  = usedCt;
     int     colNo = 0;
 
+    if (HAVE_OPT( SEPARATION ))
+        trim_last_separation();
+
     if (pzFirstPfx != NULL)
         fputs(pzFirstPfx, stdout);
 
@@ -674,10 +700,13 @@ writeFill( void )
          *  Blank lines are magical and trigger a blank line in output.
          */
         if (*pzL == NUL) {
-            if (colNo > 0) /* guard against multiple blank lines */
+            if (! HAVE_OPT(SORT)) {
+                if (colNo > 0) /* guard against multiple blank lines */
+                    putc('\n', stdout);
                 putc('\n', stdout);
-            putc('\n', stdout);
-            colNo = -2;
+                colNo = -2;
+            }
+
             free(*(ppzLL++));
             continue;
         }
@@ -704,7 +733,11 @@ writeFill( void )
 
         free(*(ppzLL++));
     }
-    putc( '\n', stdout );
+
+    if (HAVE_OPT(ENDING) && (left == 0))
+        fputs(OPT_ARG(ENDING), stdout);
+
+    putc('\n', stdout);
 }
 
 
@@ -712,11 +745,11 @@ writeFill( void )
  *  Line comparison procedure
  */
 static int
-compProc( const void* p1, const void* p2 )
+compProc(const void * p1, const void * p2)
 {
-    char const* pz1 = *(char* const*)p1;
-    char const* pz2 = *(char* const*)p2;
-    return strcmp( pz1, pz2 );
+    char const * pz1 = *(char* const*)p1;
+    char const * pz2 = *(char* const*)p2;
+    return strcmp(pz1, pz2);
 }
 /*
  * Local Variables:
